import Lib
main = basicTest $ defaultConfig { message = "Basic Test Version 2.0" }
